@@ -3,6 +3,7 @@ from PIL import Image
 from io import BytesIO
 from datetime import datetime
 from collections import defaultdict
+from importlib import resources
 
 from .base_rust_api import BaseRustSocket
 from .structures import RustInfo, RustMap, RustMarker, RustChatMessage, RustTeamInfo, RustEntityInfo, RustContents, \
@@ -11,17 +12,17 @@ from .remote.rustplus_pb2 import *
 from .remote import HeartBeat
 from ..commands import CommandOptions
 from ..exceptions import *
-from ..utils import *
+from ..utils import RustTime, format_time, format_coord, convert_marker, convert_monument, translate_id_to_stack, deprecated
 
 
 class RustSocket(BaseRustSocket):
 
     def __init__(self, ip: str = None, port: str = None, steamid: int = None, playertoken: int = None,
                  command_options: CommandOptions = None, raise_ratelimit_exception: bool = True,
-                 ratelimit_limit: int = 25, ratelimit_refill: int = 3) -> None:
+                 ratelimit_limit: int = 25, ratelimit_refill: int = 3, use_proxy: bool = False) -> None:
         super().__init__(ip=ip, port=port, steamid=steamid, playertoken=playertoken, command_options=command_options,
                          raise_ratelimit_exception=raise_ratelimit_exception, ratelimit_limit=ratelimit_limit,
-                         ratelimit_refill=ratelimit_refill, heartbeat=HeartBeat(self))
+                         ratelimit_refill=ratelimit_refill, heartbeat=HeartBeat(self), use_proxy=use_proxy)
 
     async def get_time(self) -> RustTime:
 
@@ -252,7 +253,7 @@ class RustSocket(BaseRustSocket):
         return [marker for marker in (await self.get_markers()) if
                 marker.type == 2 or marker.type == 4 or marker.type == 5 or marker.type == 6 or marker.type == 8]
 
-    async def get_tc_storage_contents(self, eid: int = None, combine_stacks: bool = False) -> RustContents:
+    async def get_contents(self, eid: int = None, combine_stacks: bool = False) -> RustContents:
 
         if eid is None:
             raise ValueError("EID cannot be None")
@@ -284,3 +285,7 @@ class RustSocket(BaseRustSocket):
                     RustItem(translate_id_to_stack(key), key, int(merged_map[key][0]), bool(merged_map[key][1])))
 
         return RustContents(difference, bool(returned_data.hasProtection), items)
+
+    @deprecated("Use RustSocket#get_contents")
+    async def get_tc_storage_contents(self, eid: int = None, combine_stacks: bool = False) -> RustContents:
+        return await self.get_contents(eid=eid, combine_stacks=combine_stacks)
